@@ -186,6 +186,8 @@ def zip_up(code_uri, zipfile_name):
             fpath = dirpath.replace(code_uri, '')  # 这一句很重要，不replace的话，就从根目录开始复制
             fpath = fpath and fpath + os.sep or ''
             for filename in filenames:
+                if 'site-packages' in fpath:
+                    fpath = fpath.replace('site-packages/','')
                 z.write(os.path.join(dirpath, filename), fpath + filename)
 
     LOG.info('%s zip suceeded!', zipfile_name)
