@@ -4,7 +4,7 @@ BCE configuration for deployment
 
 import logging
 
-from baidubce.auth.bce_credentials import BceCredentials
+from bsamcli.lib.baidubce.auth.bce_credentials import BceCredentials
 
 from bsamcli.lib.samlib.user_exceptions import DeployContextException
 from bsamcli.yamlhelper import yaml_parse
@@ -19,6 +19,7 @@ endpointMap = {
     "su": "http://cfc.su.baidubce.com",
 }
 
+
 def get_region_endpoint(region):
     region = region or get_region()
     if region is None:
